#
# spec file for package perl-Test-Deep
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Deep
Name:           perl-Test-Deep
Version:        1.205.0
Release:        1.2
# 1.205 -> normalize -> 1.205.0
%define cpan_version 1.205
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Extremely flexible deep comparison
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Test::Tester) >= 0.107
Requires:       perl(Test::More) >= 0.96
Provides:       perl(Over)
Provides:       perl(Test::Deep) = %{version}
Provides:       perl(Test::Deep::All) = %{version}
Provides:       perl(Test::Deep::Any) = %{version}
Provides:       perl(Test::Deep::Array) = %{version}
Provides:       perl(Test::Deep::ArrayEach) = %{version}
Provides:       perl(Test::Deep::ArrayElementsOnly) = %{version}
Provides:       perl(Test::Deep::ArrayLength) = %{version}
Provides:       perl(Test::Deep::ArrayLengthOnly) = %{version}
Provides:       perl(Test::Deep::Blessed) = %{version}
Provides:       perl(Test::Deep::Boolean) = %{version}
Provides:       perl(Test::Deep::Cache) = %{version}
Provides:       perl(Test::Deep::Cache::Simple) = %{version}
Provides:       perl(Test::Deep::Class) = %{version}
Provides:       perl(Test::Deep::Cmp) = %{version}
Provides:       perl(Test::Deep::Code) = %{version}
Provides:       perl(Test::Deep::Hash) = %{version}
Provides:       perl(Test::Deep::HashEach) = %{version}
Provides:       perl(Test::Deep::HashElements) = %{version}
Provides:       perl(Test::Deep::HashKeys) = %{version}
Provides:       perl(Test::Deep::HashKeysOnly) = %{version}
Provides:       perl(Test::Deep::Ignore) = %{version}
Provides:       perl(Test::Deep::Isa) = %{version}
Provides:       perl(Test::Deep::ListMethods) = %{version}
Provides:       perl(Test::Deep::MM) = %{version}
Provides:       perl(Test::Deep::Methods) = %{version}
Provides:       perl(Test::Deep::NoTest) = %{version}
Provides:       perl(Test::Deep::None) = %{version}
Provides:       perl(Test::Deep::Number) = %{version}
Provides:       perl(Test::Deep::Obj) = %{version}
Provides:       perl(Test::Deep::Ref) = %{version}
Provides:       perl(Test::Deep::RefType) = %{version}
Provides:       perl(Test::Deep::Regexp) = %{version}
Provides:       perl(Test::Deep::RegexpMatches) = %{version}
Provides:       perl(Test::Deep::RegexpOnly) = %{version}
Provides:       perl(Test::Deep::RegexpRef) = %{version}
Provides:       perl(Test::Deep::RegexpRefOnly) = %{version}
Provides:       perl(Test::Deep::RegexpVersion) = %{version}
Provides:       perl(Test::Deep::ScalarRef) = %{version}
Provides:       perl(Test::Deep::ScalarRefOnly) = %{version}
Provides:       perl(Test::Deep::Set) = %{version}
Provides:       perl(Test::Deep::Shallow) = %{version}
Provides:       perl(Test::Deep::Stack) = %{version}
Provides:       perl(Test::Deep::String) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
# necessary because Test::Deep::NoTest does "require Test::Builder"
Requires:       perl(Test::Simple)
# MANUAL END

%description
If you don't know anything about automated testing in Perl then you should
probably read about Test::Simple and Test::More before preceding.
Test::Deep uses the Test::Builder framework.

Test::Deep gives you very flexible ways to check that the result you got is
the result you were expecting. At its simplest it compares two structures
by going through each level, ensuring that the values match, that arrays
and hashes have the same elements and that references are blessed into the
correct class. It also handles circular data structures without getting
caught in an infinite loop.

Where it becomes more interesting is in allowing you to do something
besides simple exact comparisons. With strings, the 'eq' operator checks
that 2 strings are exactly equal but sometimes that's not what you want.
When you don't know exactly what the string should be but you do know some
things about how it should look, 'eq' is no good and you must use pattern
matching instead. Test::Deep provides pattern matching for complex data
structures

Test::Deep has *_a lot_* of exports. See EXPORTS below.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README TODO
%license LICENSE

%changelog
* Wed Apr  2 2025 Tina Müller <timueller+perl@suse.de>
- updated to 1.205.0 (1.205)
  see /usr/share/doc/packages/perl-Test-Deep/Changes
  1.205     2025-04-01 11:01:50-04:00 America/New_York
  - add "use v5.12" to Test::Deep, just for clarity
  - fix a test so that if an "A" module is in @INC, the tests still pass
* Wed Jun 12 2024 Dirk Stoecker <opensuse@dstoecker.de>
- refresh spec file (remove package name based requires)
* Sun Jan  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.204
  see /usr/share/doc/packages/perl-Test-Deep/Changes
  1.204     2023-01-07 18:01:37-05:00 America/New_York
  - restore v5.12 compatibility (see commit 66b79eb for the amusing
    anecdote)
  1.203     2023-01-07 11:38:14-05:00 America/New_York
  - try to avoid clobbering global error variables when loading test
    libraries (thanks, Felipe Gasper)
  - hash_each now enumates keys in sort() order, to make errors more
    consistent
  1.202     2023-01-04 20:40:46-05:00 America/New_York
  - no changes since trial releases
  - Test::Deep now requires perl v5.12.
  1.201     2023-01-03 19:28:05-05:00 America/New_York (TRIAL RELEASE)
  - correct Changes entry about which version version of perl is required
  1.200     2023-01-02 16:55:10-05:00 America/New_York (TRIAL RELEASE)
  - converted to Dist::Zilla
  - Test::Deep will now require v5.12, and this may go up.  This change
    allows simplification of the Makefile.PL, which was coping with a
    mistake made twelve years ago.
* Mon Mar  2 2020 <timueller+perl@suse.de>
- updated to 1.130
  see /usr/share/doc/packages/perl-Test-Deep/Changes
  1.130     2020-03-01
  - no changes since 1.129
  1.129     2020-01-26 - TRIAL RELEASE
  - documentation fixes (thanks, Daniel Böhmer!)
  - allow NoTest to be used without breaking other Test::Deep
    (thanks, Alexander Karelas!)
  - added true/false optional imports (thanks, Denis Ibaev!)
* Fri Apr 20 2018 coolo@suse.com
- updated to 1.128
  see /usr/share/doc/packages/perl-Test-Deep/Changes
  1.128     2018-04-18
  - numerous small improvements to documentation; thanks to
    Fabrice Gabolde, Daniel Böhmer, Lance Wicks, Matthew Horsfall
  - improved CI setup; thanks to eadjei and Philip J. Ludlam
* Sat May  6 2017 coolo@suse.com
- updated to 1.127
  see /usr/share/doc/packages/perl-Test-Deep/Changes
  1.127     2017-05-04
  - no code changes from previous release
  1.126_001 2017-04-17
  - do not eagerly convert simple scalars into tests in the all, any, and
    none tests; this was breaking LeafWrapper application
* Fri Jan  6 2017 coolo@suse.com
- updated to 1.126
  see /usr/share/doc/packages/perl-Test-Deep/Changes
* Tue Mar 10 2015 ncutler@suse.com
- add "Requires: perl-Test-Simple" to spec (hidden dependency
  not caught by cpanspec)
* Tue Mar 10 2015 ncutler@suse.com
- updated to 0.115
  - worked around a bug in chained goto on 5.8.5
  - improve prereqs metadata (thanks, Karen Etheridge)
  - add a noneof() set test (thanks, Peter Haworth)
  - regexponly hasn't worked... ever. now it does
  - passing :preload to import loads all plugins up front
  - a few more tests have been documented
  - the many exports of Test::Deep are now documented!
  - fix a compile error (!!) in RegexpOnly
  - fix some documentation typos (thanks, ZOFFIX)
  - add license to META file
* Mon Dec  9 2013 coolo@suse.com
- updated to 0.112
  - rebuild MANIFEST, adding two forgotten files
  - When printing diagnostics, differentiate the type of a blessed object
    from the name of the class itself (RT#78288, caused by changes to how
    blessed objects are treated in 0.109) (thanks, Karen Etheridge)
  - Typo fixes (thanks, David Steinbrunner)
  - Fixes to clarity and accuracy of documentation (thanks, Michael Hamlin)
  - Add metadata links to repo and issue tracker
  - Added obj_isa for testing ->isa without falling back to ref($x)
  - Added the *experimental* ":v1" export group to skip importing
    Isa, isa, and blessed
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.110
    Allow methods() and listmethods() to work again on class methods
    (RT#77804) (thanks, Ricardo Signes!)
* Mon Feb 20 2012 coolo@suse.com
- updated to 0.109
    UNIVERSAL::isa and UNIVERAL::can are no longer called as functions:
    this was deprecated in UNIVERSAL 1.03. (RT#74760, Karen Etheridge)
    the code that builds the exporter configuration is cleaned up; more
    documentation of how it may change (for the better, without breaking
    stuff) should appear in the near future
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Oct 16 2010 chris@computersalat.de
- update to 0.108
  o simple (stringwise) comparison should now be much faster
    (thanks, NCLEATON)
- fix deps
* Thu Sep 30 2010 chris@computersalat.de
- update to 0.107
  o New maintainer:  Ricardo Signes (rjbs)
  o On 5.10.0 and newer perl, install to the "site" directory, not the
    core perl directory in @INC.  (Prior to 5.10.0, @INC ordering was
    unfortunate, and fixing the install target would make upgrading
    difficult.)
  o cope with new stringification of qr{} objects in 5.13.x+ (thanks,
    ANDK)
  o fix Pod escaping errors (thanks, FWIE)
- noarch pkg
- recreated by cpanspec 1.78
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Sep  7 2009 mls@suse.de
- update to 0.106 to make it build with perl-5.10.1
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sat Jun 20 2009 chris@computersalat.de
- initial obs package 0.104
